pub struct OneofDescriptor { /* private fields */ }Expand description
Handle to one oneof declaration in a MessageDescriptor.
Implementations
Sourceimpl OneofDescriptor
impl OneofDescriptor
Sourcepub fn is_synthetic(&self) -> bool
pub fn is_synthetic(&self) -> bool
True iff this oneof was synthesized for a proto3 optional field.
Synthetic oneofs are part of the descriptor model but do not generate
any user-facing oneof Rust enum.
Sourcepub fn parent_message(&self) -> MessageDescriptor
pub fn parent_message(&self) -> MessageDescriptor
Owning message.
Sourcepub fn fields(&self) -> impl ExactSizeIterator<Item = FieldDescriptor> + '_
pub fn fields(&self) -> impl ExactSizeIterator<Item = FieldDescriptor> + '_
Iterate over the fields belonging to this oneof.
Sourcepub fn descriptor_proto(&self) -> &OneofDescriptorProto
pub fn descriptor_proto(&self) -> &OneofDescriptorProto
Raw OneofDescriptorProto for advanced use.